Symbol

Struct Symbol 

pub struct Symbol(u8);
An ASCII printable byte suitable for use as a base64 symbol in an alphabet or as custom padding.

This doesn’t mean that a particular symbol is used in any particular alphabet, just that it could be used in one.

Tuple Fields

0: u8

Implementations

Source

impl Symbol

pub const fn new(symbol: u8) -> Option<Self>

Returns Some if symbol is a valid printable ASCII symbol, otherwise None.

pub const fn as_u8(&self) -> u8

Returns the symbol as an ASCII byte.

pub fn as_char(&self) -> char

Returns the symbol as a char.