pub struct Symbol(u8);Expand description
An ASCII printable byte suitable for use as a base64 symbol in an alphabet or as custom padding.
This doesn’t mean that a particular symbol is used in any particular alphabet, just that it could be used in one.
Tuple Fields
0: u8Implementations